package org.rcisoft.bus.testgoods.controller;

import lombok.extern.slf4j.Slf4j;
import org.rcisoft.bus.common.ResponseResult;
import org.rcisoft.bus.testgoods.entity.TestGoods;
import org.rcisoft.bus.testgoods.service.TestGoodsService;
import org.rcisoft.bus.wmsgoods.entity.WmsGoods;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.List;
import java.util.UUID;

/**
 * @Author:Mr.Yang
 * @Description:Test_Object
 * @Date:2024/7/2
 * @Time:11:00
 */
@Slf4j
@RestController
@RequestMapping("/testgoods")
public class TestGoodsController {
    @Autowired
    private TestGoodsService testGoodsService;
    @Value("${localPath.path}")
    private String basePath;


    @PostMapping(value = "/add")
    public CyResult add(@Valid TestGoods testGoods) {
        return testGoodsService.addGood(testGoods);
    }

    @GetMapping(value = "/findAll")
    public CyResult findAll(TestGoods testGoods) {
        return testGoodsService.findAll(testGoods);
    }

    @GetMapping("/remove/{id}")
    public CyResult removeLogical(@PathVariable int id) {
        return testGoodsService.removeLogical(id);
    }

    @GetMapping("/find/{id}")
    public CyResult findById(@PathVariable int id) {
        return testGoodsService.findById(id);
    }

    @PostMapping("/update")
    public CyResult updateGood(TestGoods testGoods) {
        return testGoodsService.updateGood(testGoods);
    }


    @PostMapping("/upload")
    public ResponseResult<String> upload(@RequestParam(name = "file") MultipartFile files) {

        //file是一个临时文件，需要转存到指定位置，否则本次请求完成后临时文件会删除
        log.info("文件上传与下载：{}", files.toString());

        //使用原始文件名
        String originalFilename = files.getOriginalFilename();

        //截取文件名后缀l.jpg

        String suffix = null;
        if (originalFilename != null) {

            suffix = originalFilename.substring(originalFilename.lastIndexOf("."));
        }

        //使用UUID重新生成文件名，防止文件名称重复造成文件覆盖
        String fileName = UUID.randomUUID() + suffix;

        //创建一个目录对象
        File file = new File(basePath);

        //判断当前对象是否存在
        if (!file.exists()) {

            //不存在则创建目录
            file.mkdirs();
        }
        try {
            //将临时文件转存到指定位置
            files.transferTo(new File(basePath + fileName));

        } catch (IOException e) {
            e.printStackTrace();
        }

        return ResponseResult.success(fileName);
    }

    /**
     * 文件的下载及回显
     *
     * @param: name, response
     * @date: 2023/11/27 16:37
     */

    @GetMapping("/download")
    public void download(String name, HttpServletResponse response) {

        try {
            //输入流，通过输入流来读取文件内容
            FileInputStream fileInputStream = new FileInputStream(basePath + name);

            //输出流。通过输出流将文件写回浏览器，在浏览器展示图片
            ServletOutputStream outputStream = response.getOutputStream();

            //设置下载文件类型
            response.setContentType("image/jpeg");

            int len;
            byte[] bytes = new byte[1024];

            while ((len = fileInputStream.read(bytes)) != -1) {

                outputStream.write(bytes, 0, len);
                outputStream.flush();
            }

            //关闭资源
            outputStream.close();
            fileInputStream.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @GetMapping(value = "/export")
    public void outWmsGoods(HttpServletResponse response, TestGoods testGoods, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "商品信息表信息.xls";
                break;
            case "1":
                excelName = "商品信息表信息.xlsx";
                break;
            case "2":
                excelName = "商品信息表信息.csv";
                break;
        }
        List<TestGoods> testGoodsList = testGoodsService.export(testGoods);
        log.info(testGoodsList.toString());
        CyEpExcelUtil.exportExcel(testGoodsList, "商品信息表信息", "商品信息表信息", WmsGoods.class, excelName, response);
    }
}


